@@ -228,7 +228,7 @@ class _WalkCoreSchema:
     def handle_definitions_schema(self, schema: core_schema.DefinitionsSchema, f: Walk) -> core_schema.CoreSchema:
         new_definitions: list[core_schema.CoreSchema] = []
         for definition in schema['definitions']:
-            if 'schema_ref' and 'ref' in definition:
+            if 'schema_ref' in definition and 'ref' in definition:
                 # This indicates a purposely indirect reference
                 # We want to keep such references around for implications related to JSON schema, etc.:
                 new_definitions.append(definition)
